@@ -7,6 +7,8 @@ Created with love by Sigmoid
 import numpy as np
 from sklearn.feature_selection import f_classif, f_regression
 import pandas as pd
+from .errors import MissingDataError, NonNumericDataError, NoSuchColumnError
+
 class ANOVASelector:
     def __init__(self, significance_level : float = 0.05, classification : bool = True) -> None:
         '''
@@ -19,6 +21,7 @@ class ANOVASelector:
         self.significance_level = significance_level
         self.classification = classification
         self.iter = 0
+
     def bin_to_cols(self, feature_state : list, X_column : list) -> list:
         '''
             Converting the binary state list into names of features that are included in model
@@ -33,18 +36,35 @@ class ANOVASelector:
         included_columns = [X_column[i] for i in range(len(feature_state)) if feature_state[i]==1]
         return included_columns
 
-    def select(self, dataframe : 'pd.DataFrame', y_column : str) -> list:
+    def select(self, dataframe : 'pd.DataFrame', target : str) -> list:
         '''
             Selecting the most important columns
         :param dataframe: pandas DataFrame
              Data Frame on which the algorithm is applied
-        :param y_column: str
+        :param target: str
              The column name of the value that we what to predict
         :return: list
             The list of features that are selected by the algorithm as the best one
         '''
+        # Checking if in the passed data are any NaN values.
+        if dataframe.isna().values.any():
+            raise MissingDataError(
+                "The passed data frame contains missing values!"
+            )
+
+        # Checking if in the passed data are non-numeric values.
+        for col in dataframe:
+            if not pd.api.types.is_numeric_dtype(dataframe[col]):
+                raise NonNumericDataError('The given DataFrame contains non-numeric values !')
+
+        # Checking if the passed target column name is present in the passed data frame.
+        if target not in dataframe:
+            raise NoSuchColumnError(
+                "The passed target column doesn't exist!"
+            )
+
         # Defining the list with names of columns except the predicted one
-        X_columns = [col for col in dataframe.columns if col != y_column]
+        X_columns = [col for col in dataframe.columns if col != target]
 
         # Creating the F and p-value history dictionaries
         self.F_history = {}
@@ -61,7 +81,7 @@ class ANOVASelector:
             # Extracting the selected columns
             X_cols = self.bin_to_cols(feature_state, X_columns)
             X = dataframe[X_cols].values
-            y = dataframe[y_column].values
+            y = dataframe[target].values
 
             # Choosing different strategy depending whatever it is a classification or regression.
             if self.classification:
