@@ -8,6 +8,7 @@ import statsmodels.api as sm
 import numpy as np
 import matplotlib.pyplot as plt
 import pandas as pd
+from .errors import NoSuchColumnError, MissingDataError, NonNumericDataError
 class PValueSelector:
     def __init__(self, significance_level : float = 0.05) -> None:
         '''
@@ -32,21 +33,38 @@ class PValueSelector:
         included_columns = [X_column[i] for i in range(len(feature_state)) if feature_state[i]==1]
         return included_columns
 
-    def select(self, dataframe : 'pd.DataFrame', y_column : str) -> list:
+    def select(self, dataframe : 'pd.DataFrame', target : str) -> list:
         '''
             Selecting the most important columns
         :param dataframe: pandas DataFrame
             Data Frame on which the algorithm is applied
-        :param y_column: string
+        :param target: string
             The column name of the value that we what to predict
         :return: list
             The list of features that are selected by the algorithm as the best one
         '''
+        # Checking if in the passed data are any NaN values.
+        if dataframe.isna().values.any():
+            raise MissingDataError(
+                "The passed data frame contains missing values!"
+            )
+
+        # Checking if in the passed data are non-numeric values.
+        for col in dataframe:
+            if not pd.api.types.is_numeric_dtype(dataframe[col]):
+                raise NonNumericDataError('The given DataFrame contains non-numeric values !')
+
+        # Checking if the passed target column name is present in the passed data frame.
+        if target not in dataframe:
+            raise NoSuchColumnError(
+                "The passed target column doesn't exist!"
+            )
+
         # Defining the empty dictionary with the p-value history
         self.history = {}
 
         # Defining the list with names of columns except the predicted one
-        X_columns = [col for col in dataframe.columns if col != y_column]
+        X_columns = [col for col in dataframe.columns if col != target]
         for col in X_columns:
             self.history[col] = []
 
@@ -58,7 +76,7 @@ class PValueSelector:
             # Extracting the selected columns
             X_cols = self.bin_to_cols(feature_state, X_columns)
             X = dataframe[X_cols].values
-            y = dataframe[y_column].values
+            y = dataframe[target].values
 
             # Fitting the OLS model from statsmodels
             regressor_OLS = sm.OLS(y, X).fit()
